@@ -448,7 +448,8 @@ class MersenneTwister_TestBasicOps(TestBasicOps):
         self.assertRaises(TypeError, self.gen.getrandbits)
         self.assertRaises(TypeError, self.gen.getrandbits, 'a')
         self.assertRaises(TypeError, self.gen.getrandbits, 1, 2)
-        self.assertRaises(ValueError, self.gen.getrandbits, 0)
+        if sys.version_info < (3, 9):
+            self.assertRaises(ValueError, self.gen.getrandbits, 0)
         self.assertRaises(ValueError, self.gen.getrandbits, -1)
 
     def test_randbelow_logic(self, _log=log, int=int):
@@ -591,12 +592,15 @@ class TestModule(unittest.TestCase):
 #        print(counts)
 
 def test_suite():
-    return unittest.TestSuite((
-            unittest.makeSuite(WichmannHill_TestBasicOps),
-            unittest.makeSuite(MersenneTwister_TestBasicOps),
-            unittest.makeSuite(TestDistributions),
-            unittest.makeSuite(TestModule)
-            ))
+    suite = unittest.TestSuite()
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(WichmannHill_TestBasicOps))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(MersenneTwister_TestBasicOps))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(TestDistributions))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(TestModule))
+    return suite
+
 
 if __name__ == "__main__":
-    test_main(verbose=True)
+    runner = unittest.TextTestRunner(verbosity=3)
+    result = runner.run(test_suite())
+    #test_main(verbose=True)
